==> jc-1.4.0.tar.gz: java/rmi/RemoteException.h <==
// public class java.rmi.RemoteException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 512cf355dcdeb26d java_rmi_RemoteException

// header file dependencies
// @dep_header java_io_IOException

#include "java/io/IOException.h"

#ifndef _JC_java_rmi_RemoteException_H_
#define _JC_java_rmi_RemoteException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_java_rmi_RemoteException$sub_refs	_jc_java_rmi_RemoteException$sub_refs;
typedef struct _jc_java_rmi_RemoteException$sub_nonrefs	_jc_java_rmi_RemoteException$sub_nonrefs;
typedef struct _jc_java_rmi_RemoteException$refs	_jc_java_rmi_RemoteException$refs;
typedef struct _jc_java_rmi_RemoteException$nonrefs	_jc_java_rmi_RemoteException$nonrefs;
typedef struct _jc_java_rmi_RemoteException$object	_jc_java_rmi_RemoteException$object;

typedef struct _jc_java_rmi_RemoteException$fields_struct	_jc_java_rmi_RemoteException$fields_struct;
typedef const struct _jc_java_rmi_RemoteException$vmethods	_jc_java_rmi_RemoteException$vmethods;
typedef const struct _jc_java_rmi_RemoteException$vtable	_jc_java_rmi_RemoteException$vtable;
typedef const struct _jc_java_rmi_RemoteException$vtype	_jc_java_rmi_RemoteException$vtype;

// Class fields structure
struct _jc_java_rmi_RemoteException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_RemoteException$fields_struct _jc_java_rmi_RemoteException$class_fields;

// Constructors
extern void _jc_java_rmi_RemoteException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_rmi_RemoteException$object *);
extern void _jc_java_rmi_RemoteException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_rmi_RemoteException$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_rmi_RemoteException$method$_init$e87bb26efeed946b(_jc_env *, struct _jc_java_rmi_RemoteException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *);

// Virtual methods
extern struct _jc_java_lang_Throwable$object *_jc_java_rmi_RemoteException$method$getCause$d5a96efc8523817a(_jc_env *, struct _jc_java_rmi_RemoteException$object *);
extern struct _jc_java_lang_String$object *_jc_java_rmi_RemoteException$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_java_rmi_RemoteException$object *);

// Virtual method descriptors
extern _jc_method _jc_java_rmi_RemoteException$method_info$getCause$d5a96efc8523817a;
extern _jc_method _jc_java_rmi_RemoteException$method_info$getMessage$13aaf240efc902b1;

// Virtual methods structure
struct _jc_java_rmi_RemoteException$vmethods {
	struct _jc_java_lang_Throwable$object	*(*getCause$d5a96efc8523817a)(_jc_env *, struct _jc_java_rmi_RemoteException$object *);
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_java_rmi_RemoteException$object *);
};

// Vtable
struct _jc_java_rmi_RemoteException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_rmi_RemoteException$vmethods	java_rmi_RemoteException;
};

// Vtype
struct _jc_java_rmi_RemoteException$vtype {
	_jc_type			type;
	_jc_java_rmi_RemoteException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_RemoteException$sub_refs {
	struct _jc_java_lang_Throwable$object	*detail;
};

// Reference instance fields (object)
struct _jc_java_rmi_RemoteException$refs {
    _jc_java_rmi_RemoteException$sub_refs	java_rmi_RemoteException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_RemoteException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_RemoteException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_rmi_RemoteException$sub_nonrefs	java_rmi_RemoteException;
};

// Object instance structure
struct _jc_java_rmi_RemoteException$object {
	_jc_java_rmi_RemoteException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_RemoteException$vtype	*vtype;
	_jc_java_rmi_RemoteException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_RemoteException$vtype _jc_java_rmi_RemoteException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_RemoteException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_RemoteException$class_object;

#endif	/* _JC_java_rmi_RemoteException_H_ */

==> jc-1.4.6.tar.gz: java/rmi/RemoteException.h <==
// public class java.rmi.RemoteException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 512cf355dcdeb26d java_rmi_RemoteException

// header file dependencies
// @dep_header java_io_IOException

#include "java/io/IOException.h"

#ifndef _JC_java_rmi_RemoteException_H_
#define _JC_java_rmi_RemoteException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_java_rmi_RemoteException$sub_refs	_jc_java_rmi_RemoteException$sub_refs;
typedef struct _jc_java_rmi_RemoteException$sub_nonrefs	_jc_java_rmi_RemoteException$sub_nonrefs;
typedef struct _jc_java_rmi_RemoteException$refs	_jc_java_rmi_RemoteException$refs;
typedef struct _jc_java_rmi_RemoteException$nonrefs	_jc_java_rmi_RemoteException$nonrefs;
typedef struct _jc_java_rmi_RemoteException$object	_jc_java_rmi_RemoteException$object;

typedef struct _jc_java_rmi_RemoteException$fields_struct	_jc_java_rmi_RemoteException$fields_struct;
typedef const struct _jc_java_rmi_RemoteException$vmethods	_jc_java_rmi_RemoteException$vmethods;
typedef const struct _jc_java_rmi_RemoteException$vtable	_jc_java_rmi_RemoteException$vtable;
typedef const struct _jc_java_rmi_RemoteException$vtype	_jc_java_rmi_RemoteException$vtype;

// Class fields structure
struct _jc_java_rmi_RemoteException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_RemoteException$fields_struct _jc_java_rmi_RemoteException$class_fields;

// Constructors
extern void _jc_java_rmi_RemoteException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_rmi_RemoteException$object *) _JC_JCNI_ATTR;
extern void _jc_java_rmi_RemoteException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_rmi_RemoteException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_rmi_RemoteException$method$_init$e87bb26efeed946b(_jc_env *, struct _jc_java_rmi_RemoteException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Throwable$object *_jc_java_rmi_RemoteException$method$getCause$d5a96efc8523817a(_jc_env *, struct _jc_java_rmi_RemoteException$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_rmi_RemoteException$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_java_rmi_RemoteException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_rmi_RemoteException$method_info$getCause$d5a96efc8523817a;
extern _jc_method _jc_java_rmi_RemoteException$method_info$getMessage$13aaf240efc902b1;

// Virtual methods structure
struct _jc_java_rmi_RemoteException$vmethods {
	struct _jc_java_lang_Throwable$object	*(*getCause$d5a96efc8523817a)(_jc_env *, struct _jc_java_rmi_RemoteException$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_java_rmi_RemoteException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_rmi_RemoteException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_rmi_RemoteException$vmethods	java_rmi_RemoteException;
};

// Vtype
struct _jc_java_rmi_RemoteException$vtype {
	_jc_type			type;
	_jc_java_rmi_RemoteException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_RemoteException$sub_refs {
	struct _jc_java_lang_Throwable$object	*detail;
};

// Reference instance fields (object)
struct _jc_java_rmi_RemoteException$refs {
    _jc_java_rmi_RemoteException$sub_refs	java_rmi_RemoteException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_RemoteException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_RemoteException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_rmi_RemoteException$sub_nonrefs	java_rmi_RemoteException;
};

// Object instance structure
struct _jc_java_rmi_RemoteException$object {
	_jc_java_rmi_RemoteException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_RemoteException$vtype	*vtype;
	_jc_java_rmi_RemoteException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_RemoteException$vtype _jc_java_rmi_RemoteException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_RemoteException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_RemoteException$class_object;

#endif	/* _JC_java_rmi_RemoteException_H_ */
